pub enum ChannelOffloadExtRequest {
StartOffload {
payload: ChannelOffloadExtStartOffloadRequest,
responder: ChannelOffloadExtStartOffloadResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: ChannelOffloadExtControlHandle,
method_type: MethodType,
},
}Expand description
Protocol extension for a bt.Channel. This is typically provided by or to
privileged clients alongside a bt.Channel. This protocol can be closed
before or after StartOffload has returned with no effect.
Variants
StartOffload
StartOffload MUST be called before Channel.Receive(). The offloaded channel will have 0 RX credits given to the peer to prevent the peer from sending data until the offload processor is ready. This method may be called a maximum of one time.
The following errors may be returned:
- error
BAD_STATE: Channel.Receive() has already been called or StartOffload() has already been called. - error
INTERNAL: An internal error occurred and the channel could not be offloaded.
Fields

responder: ChannelOffloadExtStartOffloadResponder#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: ChannelOffloadExtControlHandle
method_type: MethodTypeImplementations
Sourceimpl ChannelOffloadExtRequest
impl ChannelOffloadExtRequest
pub fn into_start_offload( self, ) -> Option<(ChannelOffloadExtStartOffloadRequest, ChannelOffloadExtStartOffloadResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL