pub enum ConnectedIsochronousGroupRequest {
EstablishStreams {
payload: ConnectedIsochronousGroupEstablishStreamsRequest,
responder: ConnectedIsochronousGroupEstablishStreamsResponder,
},
Remove {
control_handle: ConnectedIsochronousGroupControlHandle,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: ConnectedIsochronousGroupControlHandle,
method_type: MethodType,
},
}Variants
EstablishStreams
Connect one or more Isochronous streams. Each CIS is established with the peer specified in the parameters. On successful initiation of the operation, an OnEstablished() event will be sent on the IsochronousStream.
Only one EstablishStreams call may be active at a time. Calling EstablishStreams while
another is pending will result in the channel being closed with ZX_ERR_BAD_STATE.
On error, no CISes are established and an appropriate EstablishStreamsError code will be
returned.
Otherwise, this call returns once each CIS specified has connected.
Fields
Remove
Remove this CIG. Associated streams will be closed. This protocol will be closed after all of the associated streams have closed and the group has been removed.
Fields
control_handle: ConnectedIsochronousGroupControlHandle#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
control_handle: ConnectedIsochronousGroupControlHandlemethod_type: MethodTypeImplementations
Sourceimpl ConnectedIsochronousGroupRequest
impl ConnectedIsochronousGroupRequest
pub fn into_establish_streams( self, ) -> Option<(ConnectedIsochronousGroupEstablishStreamsRequest, ConnectedIsochronousGroupEstablishStreamsResponder)>
pub fn into_remove(self) -> Option<ConnectedIsochronousGroupControlHandle>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL