BroadcastIsochronousGroupInfo

Struct BroadcastIsochronousGroupInfo 

pub struct BroadcastIsochronousGroupInfo {
    pub streams_count: Option<u8>,
    pub max_sdu_size: Option<u16>,
    pub phy: Option<PhysicalLayer>,
    pub encryption: Option<bool>,
    /* private fields */
}
The “BIGInfo” parameters describing an LE Audio Broadcast Isochronous Group (BIG). Missing fields to be added as part of fxbug.dev/429213165.

Fields

streams_count: Option<u8>

The number of Broadcast Isochronous Streams in this group.

max_sdu_size: Option<u16>

The maximum size of an isochronous SDU.

phy: Option<PhysicalLayer>

The PHY used for transmission of data.

encryption: Option<bool>

Indicates whether the BIG is encrypted.