pub struct ChannelOffloadExtMarker;Trait Implementations
Sourceimpl Clone for ChannelOffloadExtMarker
impl Clone for ChannelOffloadExtMarker
Sourcefn clone(&self) -> ChannelOffloadExtMarker
fn clone(&self) -> ChannelOffloadExtMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChannelOffloadExtMarker
impl Debug for ChannelOffloadExtMarker
Sourceimpl Hash for ChannelOffloadExtMarker
impl Hash for ChannelOffloadExtMarker
Sourceimpl Ord for ChannelOffloadExtMarker
impl Ord for ChannelOffloadExtMarker
Sourcefn cmp(&self, other: &ChannelOffloadExtMarker) -> Ordering
fn cmp(&self, other: &ChannelOffloadExtMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChannelOffloadExtMarker
impl PartialEq for ChannelOffloadExtMarker
Sourceimpl PartialOrd for ChannelOffloadExtMarker
impl PartialOrd for ChannelOffloadExtMarker
Sourceimpl ProtocolMarker for ChannelOffloadExtMarker
impl ProtocolMarker for ChannelOffloadExtMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) ChannelOffloadExt"
const DEBUG_NAME: &'static str = "(anonymous) ChannelOffloadExt"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = ChannelOffloadExtProxy
type Proxy = ChannelOffloadExtProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = ChannelOffloadExtRequestStream
type RequestStream = ChannelOffloadExtRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = ChannelOffloadExtSynchronousProxy
type SynchronousProxy = ChannelOffloadExtSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for ChannelOffloadExtMarker
impl Eq for ChannelOffloadExtMarker
impl StructuralPartialEq for ChannelOffloadExtMarker