pub struct ChannelOffloadExtProxy { /* private fields */ }Implementations
Sourceimpl ChannelOffloadExtProxy
impl ChannelOffloadExtProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.bluetooth.le/ChannelOffloadExt.
Sourcepub fn take_event_stream(&self) -> ChannelOffloadExtEventStream
pub fn take_event_stream(&self) -> ChannelOffloadExtEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn start_offload(
&self,
payload: &ChannelOffloadExtStartOffloadRequest,
) -> QueryResponseFut<ChannelOffloadExtStartOffloadResult, DefaultFuchsiaResourceDialect>
pub fn start_offload( &self, payload: &ChannelOffloadExtStartOffloadRequest, ) -> QueryResponseFut<ChannelOffloadExtStartOffloadResult, DefaultFuchsiaResourceDialect>
StartOffload MUST be called before Channel.Receive(). The offloaded channel will have 0 RX credits given to the peer to prevent the peer from sending data until the offload processor is ready. This method may be called a maximum of one time.
The following errors may be returned:
- error
BAD_STATE: Channel.Receive() has already been called or StartOffload() has already been called. - error
INTERNAL: An internal error occurred and the channel could not be offloaded.