pub struct ChannelOffloadExtStartOffloadRequest { /* private fields */ }Trait Implementations
Sourceimpl Clone for ChannelOffloadExtStartOffloadRequest
impl Clone for ChannelOffloadExtStartOffloadRequest
Sourcefn clone(&self) -> ChannelOffloadExtStartOffloadRequest
fn clone(&self) -> ChannelOffloadExtStartOffloadRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<ChannelOffloadExtStartOffloadRequest, D> for ChannelOffloadExtStartOffloadRequestwhere
D: ResourceDialect,
impl<D> Decode<ChannelOffloadExtStartOffloadRequest, D> for ChannelOffloadExtStartOffloadRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> ChannelOffloadExtStartOffloadRequest
fn new_empty() -> ChannelOffloadExtStartOffloadRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for ChannelOffloadExtStartOffloadRequest
impl Default for ChannelOffloadExtStartOffloadRequest
Sourcefn default() -> ChannelOffloadExtStartOffloadRequest
fn default() -> ChannelOffloadExtStartOffloadRequest
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<ChannelOffloadExtStartOffloadRequest, D> for &ChannelOffloadExtStartOffloadRequestwhere
D: ResourceDialect,
impl<D> Encode<ChannelOffloadExtStartOffloadRequest, D> for &ChannelOffloadExtStartOffloadRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for ChannelOffloadExtStartOffloadRequest
impl PartialEq for ChannelOffloadExtStartOffloadRequest
Sourcefn eq(&self, other: &ChannelOffloadExtStartOffloadRequest) -> bool
fn eq(&self, other: &ChannelOffloadExtStartOffloadRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for ChannelOffloadExtStartOffloadRequest
impl TypeMarker for ChannelOffloadExtStartOffloadRequest
Sourcetype Owned = ChannelOffloadExtStartOffloadRequest
type Owned = ChannelOffloadExtStartOffloadRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ChannelOffloadExtStartOffloadRequest
impl ValueTypeMarker for ChannelOffloadExtStartOffloadRequest
Sourcetype Borrowed<'a> = &'a ChannelOffloadExtStartOffloadRequest
type Borrowed<'a> = &'a ChannelOffloadExtStartOffloadRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ChannelOffloadExtStartOffloadRequest as TypeMarker>::Owned,
) -> <ChannelOffloadExtStartOffloadRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ChannelOffloadExtStartOffloadRequest as TypeMarker>::Owned, ) -> <ChannelOffloadExtStartOffloadRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for ChannelOffloadExtStartOffloadRequest
impl StructuralPartialEq for ChannelOffloadExtStartOffloadRequest