pub struct ChannelOffloadExtSynchronousProxy { /* private fields */ }Implementations
Sourceimpl ChannelOffloadExtSynchronousProxy
impl ChannelOffloadExtSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<ChannelOffloadExtEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<ChannelOffloadExtEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn start_offload(
&self,
payload: &ChannelOffloadExtStartOffloadRequest,
___deadline: MonotonicInstant,
) -> Result<ChannelOffloadExtStartOffloadResult, Error>
pub fn start_offload( &self, payload: &ChannelOffloadExtStartOffloadRequest, ___deadline: MonotonicInstant, ) -> Result<ChannelOffloadExtStartOffloadResult, Error>
StartOffload MUST be called before Channel.Receive(). The offloaded channel will have 0 RX credits given to the peer to prevent the peer from sending data until the offload processor is ready. This method may be called a maximum of one time.
The following errors may be returned:
- error
BAD_STATE: Channel.Receive() has already been called or StartOffload() has already been called. - error
INTERNAL: An internal error occurred and the channel could not be offloaded.