pub struct CigParameters {
pub sdu_interval_c_to_p: Option<u32>,
pub sdu_interval_p_to_c: Option<u32>,
pub packing: Option<CigPacking>,
pub framing: Option<CigFramingOptions>,
pub max_transport_latency_c_to_p: Option<u16>,
pub max_transport_latency_p_to_c: Option<u16>,
pub expected_peers: Option<Vec<PeerId>>,
/* private fields */
}Fields
sdu_interval_c_to_p: Option<u32>Interval between the start of consecutive SDUs (central => peripheral, microseconds). This is a function of the codec being used. Required.
sdu_interval_p_to_c: Option<u32>Interval between the start of consecutive SDUs (peripheral => central, microseconds). This is a function of the codec being used. Required.
packing: Option<CigPacking>The preferred method of arranging subevents of multiple CISes. The controller may ignore this parameter. Optional. If not specified, SEQUENTIAL will be used.
framing: Option<CigFramingOptions>Specifies inclusion of time offset values in data frame. Optional. If not specified, UNFRAMED will be used.
max_transport_latency_c_to_p: Option<u16>Maximum latency, in milliseconds, between controllers (central => peripheral). Required.
max_transport_latency_p_to_c: Option<u16>Maximum latency, in milliseconds, between controllers (peripheral => central). Required.
expected_peers: Option<Vec<PeerId>>The expected or intended peers to join this CIG, if known. This may be used to optimize parameters, but may limit the set of peers that can connect to the group. Optional.