PeriodicAdvertisingReport

Struct PeriodicAdvertisingReport 

pub struct PeriodicAdvertisingReport {
    pub rssi: Option<i8>,
    pub data: Option<ScanData>,
    pub event_counter: Option<u16>,
    pub subevent: Option<u8>,
    pub timestamp: Option<i64>,
    /* private fields */
}

Fields

rssi: Option<i8>

The signal strength of the advertising report.

data: Option<ScanData>

The advertising data payload sent with this report.

event_counter: Option<u16>

The event counter of the event that the advertising packet was received in. This can be used to reply to the report.

subevent: Option<u8>

The subevent number of the report. Only present if the packet was received in a subevent.

timestamp: Option<i64>

The timestamp when the report was received by the host.