pub struct PrivilegedCentralConnectPeripheralResponder { /* private fields */ }Implementations
Sourceimpl PrivilegedCentralConnectPeripheralResponder
impl PrivilegedCentralConnectPeripheralResponder
Sourcepub fn send(self, status: &Status) -> Result<(), Error>
pub fn send(self, status: &Status) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(self, status: &Status) -> Result<(), Error>
pub fn send_no_shutdown_on_err(self, status: &Status) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.