pub struct PrivilegedCentralGetPeripheralResponder { /* private fields */ }Implementations
Sourceimpl PrivilegedCentralGetPeripheralResponder
impl PrivilegedCentralGetPeripheralResponder
Sourcepub fn send(self, peripheral: Option<&RemoteDevice>) -> Result<(), Error>
pub fn send(self, peripheral: Option<&RemoteDevice>) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
peripheral: Option<&RemoteDevice>,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, peripheral: Option<&RemoteDevice>, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.