pub struct PrivilegedCentralListenL2capResponder { /* private fields */ }Implementations
Sourceimpl PrivilegedCentralListenL2capResponder
impl PrivilegedCentralListenL2capResponder
Sourcepub fn send(
self,
result: Result<&ChannelListenerRegistryListenL2capResponse, i32>,
) -> Result<(), Error>
pub fn send( self, result: Result<&ChannelListenerRegistryListenL2capResponse, i32>, ) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
result: Result<&ChannelListenerRegistryListenL2capResponse, i32>,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, result: Result<&ChannelListenerRegistryListenL2capResponse, i32>, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.