pub struct PrivilegedCentralMarker;Trait Implementations
Sourceimpl Clone for PrivilegedCentralMarker
impl Clone for PrivilegedCentralMarker
Sourcefn clone(&self) -> PrivilegedCentralMarker
fn clone(&self) -> PrivilegedCentralMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrivilegedCentralMarker
impl Debug for PrivilegedCentralMarker
Sourceimpl DiscoverableProtocolMarker for PrivilegedCentralMarker
impl DiscoverableProtocolMarker for PrivilegedCentralMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for PrivilegedCentralMarker
impl Hash for PrivilegedCentralMarker
Sourceimpl Ord for PrivilegedCentralMarker
impl Ord for PrivilegedCentralMarker
Sourcefn cmp(&self, other: &PrivilegedCentralMarker) -> Ordering
fn cmp(&self, other: &PrivilegedCentralMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PrivilegedCentralMarker
impl PartialEq for PrivilegedCentralMarker
Sourceimpl PartialOrd for PrivilegedCentralMarker
impl PartialOrd for PrivilegedCentralMarker
Sourceimpl ProtocolMarker for PrivilegedCentralMarker
impl ProtocolMarker for PrivilegedCentralMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.bluetooth.le.PrivilegedCentral"
const DEBUG_NAME: &'static str = "fuchsia.bluetooth.le.PrivilegedCentral"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = PrivilegedCentralProxy
type Proxy = PrivilegedCentralProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = PrivilegedCentralRequestStream
type RequestStream = PrivilegedCentralRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = PrivilegedCentralSynchronousProxy
type SynchronousProxy = PrivilegedCentralSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for PrivilegedCentralMarker
impl Eq for PrivilegedCentralMarker
impl StructuralPartialEq for PrivilegedCentralMarker